<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('deposit');

// 记录访问日志
record_log('访问押金管理页面');

// 初始化变量
$checkin_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$checkin_order = null;

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 收取押金
    if ($_POST['action'] == 'add_deposit') {
        $checkin_id = isset($_POST['checkin_id']) ? intval($_POST['checkin_id']) : 0;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_method = isset($_POST['payment_method']) ? intval($_POST['payment_method']) : 1;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($checkin_id <= 0 || $amount <= 0) {
            $error = '请填写有效的押金信息！';
        } else {
            try {
                // 检查入住记录是否存在且未退房
                $stmt = $pdo->prepare("
                    SELECT co.*, r.room_number 
                    FROM checkin_orders co
                    JOIN room_info r ON co.room_id = r.id
                    WHERE co.id = ? AND co.status = 1
                ");
                $stmt->execute([$checkin_id]);
                $checkin = $stmt->fetch();

                if (!$checkin) {
                    $error = '入住记录不存在或已退房！';
                } else {
                    // 开始事务
                    $pdo->beginTransaction();

                    // 记录押金交易
                    $stmt = $pdo->prepare("
                        INSERT INTO checkin_transactions (
                            checkin_id, type, amount, 
                            payment_method, operator_id, remark
                        ) VALUES (?, 4, ?, ?, ?, ?)
                    ");
                    $transaction_added = $stmt->execute([
                        $checkin_id,
                        $amount,
                        $payment_method,
                        $_SESSION['user_id'],
                        $remark ?: '收取押金'
                    ]);

                    // 更新入住记录中的押金金额
                    $stmt = $pdo->prepare("
                        UPDATE checkin_orders 
                        SET deposit_amount = deposit_amount + ? 
                        WHERE id = ?
                    ");
                    $checkin_updated = $stmt->execute([$amount, $checkin_id]);

                    if ($transaction_added && $checkin_updated) {
                        $pdo->commit();
                        record_log("收取押金：房间 {$checkin['room_number']}，客人 {$checkin['guest_name']}，金额：{$amount}");
                        $success = '押金收取成功！';
                    } else {
                        $pdo->rollBack();
                        $error = '押金收取失败！';
                    }
                }
            } catch (PDOException $e) {
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 退还押金
    elseif ($_POST['action'] == 'return_deposit') {
        $checkin_id = isset($_POST['checkin_id']) ? intval($_POST['checkin_id']) : 0;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_method = isset($_POST['payment_method']) ? intval($_POST['payment_method']) : 1;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($checkin_id <= 0 || $amount <= 0) {
            $error = '请填写有效的押金信息！';
        } else {
            try {
                // 检查入住记录是否存在且未退房
                $stmt = $pdo->prepare("
                    SELECT co.*, r.room_number 
                    FROM checkin_orders co
                    JOIN room_info r ON co.room_id = r.id
                    WHERE co.id = ? AND co.status = 1
                ");
                $stmt->execute([$checkin_id]);
                $checkin = $stmt->fetch();

                if (!$checkin) {
                    $error = '入住记录不存在或已退房！';
                } elseif ($checkin['deposit_amount'] < $amount) {
                    $error = '退还金额不能大于已收押金总额！';
                } else {
                    // 开始事务
                    $pdo->beginTransaction();

                    // 记录押金退还交易
                    $stmt = $pdo->prepare("
                        INSERT INTO checkin_transactions (
                            checkin_id, type, amount, 
                            payment_method, operator_id, remark
                        ) VALUES (?, 5, ?, ?, ?, ?)
                    ");
                    $transaction_added = $stmt->execute([
                        $checkin_id,
                        $amount,
                        $payment_method,
                        $_SESSION['user_id'],
                        $remark ?: '退还押金'
                    ]);

                    // 更新入住记录中的押金金额
                    $stmt = $pdo->prepare("
                        UPDATE checkin_orders 
                        SET deposit_amount = deposit_amount - ? 
                        WHERE id = ?
                    ");
                    $checkin_updated = $stmt->execute([$amount, $checkin_id]);

                    if ($transaction_added && $checkin_updated) {
                        $pdo->commit();
                        record_log("退还押金：房间 {$checkin['room_number']}，客人 {$checkin['guest_name']}，金额：{$amount}");
                        $success = '押金退还成功！';
                    } else {
                        $pdo->rollBack();
                        $error = '押金退还失败！';
                    }
                }
            } catch (PDOException $e) {
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 扣除押金
    elseif ($_POST['action'] == 'deduct_deposit') {
        $checkin_id = isset($_POST['checkin_id']) ? intval($_POST['checkin_id']) : 0;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $reason = isset($_POST['reason']) ? trim($_POST['reason']) : '';

        if ($checkin_id <= 0 || $amount <= 0 || empty($reason)) {
            $error = '请填写完整的押金扣除信息！';
        } else {
            try {
                // 检查入住记录是否存在且未退房
                $stmt = $pdo->prepare("
                    SELECT co.*, r.room_number 
                    FROM checkin_orders co
                    JOIN room_info r ON co.room_id = r.id
                    WHERE co.id = ? AND co.status = 1
                ");
                $stmt->execute([$checkin_id]);
                $checkin = $stmt->fetch();

                if (!$checkin) {
                    $error = '入住记录不存在或已退房！';
                } elseif ($checkin['deposit_amount'] < $amount) {
                    $error = '扣除金额不能大于已收押金总额！';
                } else {
                    // 开始事务
                    $pdo->beginTransaction();

                    // 记录押金扣除交易
                    $stmt = $pdo->prepare("
                        INSERT INTO checkin_transactions (
                            checkin_id, type, amount, 
                            payment_method, operator_id, remark
                        ) VALUES (?, 6, ?, 1, ?, ?)
                    ");
                    $transaction_added = $stmt->execute([
                        $checkin_id,
                        $amount,
                        $_SESSION['user_id'],
                        '押金扣除: ' . $reason
                    ]);

                    // 更新入住记录中的押金金额和损坏信息
                    $stmt = $pdo->prepare("
                        UPDATE checkin_orders 
                        SET deposit_amount = deposit_amount - ?,
                            has_damage = 1,
                            damage_amount = damage_amount + ?,
                            remark = CONCAT(IFNULL(remark, ''), '\n损坏扣款: ', ?)
                        WHERE id = ?
                    ");
                    $checkin_updated = $stmt->execute([
                        $amount,
                        $amount,
                        $reason,
                        $checkin_id
                    ]);

                    if ($transaction_added && $checkin_updated) {
                        $pdo->commit();
                        record_log("扣除押金：房间 {$checkin['room_number']}，客人 {$checkin['guest_name']}，金额：{$amount}，原因：{$reason}");
                        $success = '押金扣除成功！';
                    } else {
                        $pdo->rollBack();
                        $error = '押金扣除失败！';
                    }
                }
            } catch (PDOException $e) {
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取入住订单详情
if ($checkin_id > 0) {
    try {
        $stmt = $pdo->prepare("
            SELECT co.*, r.room_number, t.type_name,
                  m.member_no, m.name as member_name, u.username AS operator_name
            FROM checkin_orders co
            JOIN room_info r ON co.room_id = r.id
            JOIN room_types t ON r.room_type_id = t.id
            LEFT JOIN guest_members m ON co.member_id = m.id
            LEFT JOIN sys_users u ON co.create_by = u.id
            WHERE co.id = ?
        ");
        $stmt->execute([$checkin_id]);
        $checkin_order = $stmt->fetch();

        // 获取押金交易记录
        if ($checkin_order) {
            $stmt = $pdo->prepare("
                SELECT t.*, u.username AS operator_name
                FROM checkin_transactions t
                LEFT JOIN sys_users u ON t.operator_id = u.id
                WHERE t.checkin_id = ? AND t.type IN (4, 5, 6)
                ORDER BY t.transaction_time DESC
            ");
            $stmt->execute([$checkin_id]);
            $deposit_transactions = $stmt->fetchAll();
        }
    } catch (PDOException $e) {
        $error = '获取入住详情失败：' . $e->getMessage();
    }
}

// 获取活跃的入住订单（用于下拉选择）
try {
    $stmt = $pdo->query("
        SELECT co.id, co.checkin_no, co.guest_name, r.room_number, co.deposit_amount
        FROM checkin_orders co
        JOIN room_info r ON co.room_id = r.id
        WHERE co.status = 1
        ORDER BY co.checkin_time DESC
    ");
    $active_checkins = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取入住订单列表失败：' . $e->getMessage();
    $active_checkins = [];
}

// 获取近期押金交易记录（用于列表显示）
if (!$checkin_id) {
    try {
        $stmt = $pdo->query("
            SELECT t.*, co.checkin_no, co.guest_name, r.room_number, u.username AS operator_name
            FROM checkin_transactions t
            JOIN checkin_orders co ON t.checkin_id = co.id
            JOIN room_info r ON co.room_id = r.id
            LEFT JOIN sys_users u ON t.operator_id = u.id
            WHERE t.type IN (4, 5, 6)
            ORDER BY t.transaction_time DESC
            LIMIT 20
        ");
        $recent_transactions = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取交易记录失败：' . $e->getMessage();
        $recent_transactions = [];
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>押金管理</h2>
            <div class="breadcrumb">
                <a href="index.php">入住与退房管理</a> &gt; 押金管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if (!$checkin_id): ?>
                <!-- 选择入住订单 -->
                <div class="selection-container">
                    <h3>选择入住订单</h3>
                    <form method="get" action="" class="form-inline">
                        <div class="form-group">
                            <label for="id">选择入住订单：</label>
                            <select id="id" name="id" class="form-control" onchange="this.form.submit()">
                                <option value="">请选择</option>
                                <?php foreach ($active_checkins as $checkin): ?>
                                    <option value="<?php echo $checkin['id']; ?>">
                                        <?php echo $checkin['room_number']; ?> -
                                        <?php echo $checkin['guest_name']; ?>
                                        (押金: ￥<?php echo number_format($checkin['deposit_amount'], 2); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </form>
                </div>

                <!-- 最近押金记录 -->
                <h3>最近押金交易记录</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>交易ID</th>
                                <th>入住单号</th>
                                <th>客人姓名</th>
                                <th>房间</th>
                                <th>类型</th>
                                <th>金额</th>
                                <th>支付方式</th>
                                <th>操作员</th>
                                <th>交易时间</th>
                                <th>备注</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($recent_transactions)): ?>
                                <?php foreach ($recent_transactions as $transaction): ?>
                                    <tr>
                                        <td><?php echo $transaction['id']; ?></td>
                                        <td><?php echo $transaction['checkin_no']; ?></td>
                                        <td><?php echo $transaction['guest_name']; ?></td>
                                        <td><?php echo $transaction['room_number']; ?></td>
                                        <td>
                                            <?php
                                            $type_texts = [
                                                4 => '<span class="status-active">收取押金</span>',
                                                5 => '<span class="status-inactive">退还押金</span>',
                                                6 => '<span class="status-warning">押金扣除</span>'
                                            ];
                                            echo isset($type_texts[$transaction['type']]) ? $type_texts[$transaction['type']] : '未知';
                                            ?>
                                        </td>
                                        <td>￥<?php echo number_format($transaction['amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            $payment_methods = [
                                                1 => '现金',
                                                2 => '信用卡',
                                                3 => '微信',
                                                4 => '支付宝'
                                            ];
                                            echo isset($payment_methods[$transaction['payment_method']]) ? $payment_methods[$transaction['payment_method']] : '未知';
                                            ?>
                                        </td>
                                        <td><?php echo $transaction['operator_name']; ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($transaction['transaction_time'])); ?></td>
                                        <td><?php echo $transaction['remark']; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="10" class="text-center">暂无押金交易记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <!-- 入住订单押金管理 -->
                <div class="summary-section">
                    <h3>入住信息</h3>
                    <div class="summary-grid">
                        <div class="summary-item">
                            <label>入住单号：</label>
                            <span><?php echo $checkin_order['checkin_no']; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>客人姓名：</label>
                            <span><?php echo $checkin_order['guest_name']; ?></span>
                        </div>
                        <div class="summary-item">
                            <label>房间号：</label>
                            <span><?php echo $checkin_order['room_number']; ?> (<?php echo $checkin_order['type_name']; ?>)</span>
                        </div>
                        <div class="summary-item">
                            <label>入住时间：</label>
                            <span><?php echo date('Y-m-d H:i', strtotime($checkin_order['checkin_time'])); ?></span>
                        </div>
                        <div class="summary-item">
                            <label>当前押金：</label>
                            <span class="large-text">￥<?php echo number_format($checkin_order['deposit_amount'], 2); ?></span>
                        </div>
                        <?php if ($checkin_order['status'] == 2): ?>
                            <div class="summary-item">
                                <label>退房状态：</label>
                                <span class="status-inactive">已退房</span>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <?php if ($checkin_order['status'] == 1): ?>
                    <div class="action-buttons">
                        <button class="btn btn-primary" onclick="document.getElementById('add-deposit-form').style.display='block';">收取押金</button>
                        <button class="btn btn-warning" onclick="document.getElementById('return-deposit-form').style.display='block';">退还押金</button>
                        <button class="btn btn-danger" onclick="document.getElementById('deduct-deposit-form').style.display='block';">押金扣除</button>
                        <a href="checkout.php?id=<?php echo $checkin_order['id']; ?>" class="btn btn-secondary">办理退房</a>
                    </div>

                    <!-- 收取押金表单 -->
                    <div id="add-deposit-form" class="form-popup" style="display: none;">
                        <div class="form-container">
                            <h4>收取押金</h4>
                            <form method="post" action="">
                                <input type="hidden" name="action" value="add_deposit">
                                <input type="hidden" name="checkin_id" value="<?php echo $checkin_order['id']; ?>">

                                <div class="form-group">
                                    <label for="amount">金额：</label>
                                    <input type="number" id="amount" name="amount" min="0.01" step="0.01" required>
                                </div>

                                <div class="form-group">
                                    <label for="payment_method">支付方式：</label>
                                    <select id="payment_method" name="payment_method">
                                        <option value="1">现金</option>
                                        <option value="2">信用卡</option>
                                        <option value="3">微信</option>
                                        <option value="4">支付宝</option>
                                    </select>
                                </div>

                                <div class="form-group">
                                    <label for="remark">备注：</label>
                                    <input type="text" id="remark" name="remark">
                                </div>

                                <div class="form-buttons">
                                    <button type="submit" class="btn btn-primary">确定</button>
                                    <button type="button" class="btn btn-secondary" onclick="document.getElementById('add-deposit-form').style.display='none';">取消</button>
                                </div>
                            </form>
                        </div>
                    </div>

                    <!-- 退还押金表单 -->
                    <div id="return-deposit-form" class="form-popup" style="display: none;">
                        <div class="form-container">
                            <h4>退还押金</h4>
                            <form method="post" action="">
                                <input type="hidden" name="action" value="return_deposit">
                                <input type="hidden" name="checkin_id" value="<?php echo $checkin_order['id']; ?>">

                                <div class="form-group">
                                    <label for="return_amount">金额：</label>
                                    <input type="number" id="return_amount" name="amount" min="0.01" step="0.01" max="<?php echo $checkin_order['deposit_amount']; ?>" required>
                                    <p class="form-hint">当前押金余额: ￥<?php echo number_format($checkin_order['deposit_amount'], 2); ?></p>
                                </div>

                                <div class="form-group">
                                    <label for="return_payment_method">支付方式：</label>
                                    <select id="return_payment_method" name="payment_method">
                                        <option value="1">现金</option>
                                        <option value="2">信用卡</option>
                                        <option value="3">微信</option>
                                        <option value="4">支付宝</option>
                                    </select>
                                </div>

                                <div class="form-group">
                                    <label for="return_remark">备注：</label>
                                    <input type="text" id="return_remark" name="remark">
                                </div>

                                <div class="form-buttons">
                                    <button type="submit" class="btn btn-primary">确定</button>
                                    <button type="button" class="btn btn-secondary" onclick="document.getElementById('return-deposit-form').style.display='none';">取消</button>
                                </div>
                            </form>
                        </div>
                    </div>

                    <!-- 押金扣除表单 -->
                    <div id="deduct-deposit-form" class="form-popup" style="display: none;">
                        <div class="form-container">
                            <h4>押金扣除</h4>
                            <form method="post" action="">
                                <input type="hidden" name="action" value="deduct_deposit">
                                <input type="hidden" name="checkin_id" value="<?php echo $checkin_order['id']; ?>">

                                <div class="form-group">
                                    <label for="deduct_amount">扣除金额：</label>
                                    <input type="number" id="deduct_amount" name="amount" min="0.01" step="0.01" max="<?php echo $checkin_order['deposit_amount']; ?>" required>
                                    <p class="form-hint">当前押金余额: ￥<?php echo number_format($checkin_order['deposit_amount'], 2); ?></p>
                                </div>

                                <div class="form-group">
                                    <label for="reason">扣除原因：</label>
                                    <textarea id="reason" name="reason" rows="3" required></textarea>
                                </div>

                                <div class="form-buttons">
                                    <button type="submit" class="btn btn-primary" onclick="return confirm('确定要扣除押金吗？此操作不可撤销。')">确定</button>
                                    <button type="button" class="btn btn-secondary" onclick="document.getElementById('deduct-deposit-form').style.display='none';">取消</button>
                                </div>
                            </form>
                        </div>
                    </div>
                <?php endif; ?>

                <!-- 押金交易记录 -->
                <h3>押金交易记录</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>交易ID</th>
                                <th>类型</th>
                                <th>金额</th>
                                <th>支付方式</th>
                                <th>操作员</th>
                                <th>交易时间</th>
                                <th>备注</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($deposit_transactions)): ?>
                                <?php foreach ($deposit_transactions as $transaction): ?>
                                    <tr>
                                        <td><?php echo $transaction['id']; ?></td>
                                        <td>
                                            <?php
                                            $type_texts = [
                                                4 => '<span class="status-active">收取押金</span>',
                                                5 => '<span class="status-inactive">退还押金</span>',
                                                6 => '<span class="status-warning">押金扣除</span>'
                                            ];
                                            echo isset($type_texts[$transaction['type']]) ? $type_texts[$transaction['type']] : '未知';
                                            ?>
                                        </td>
                                        <td>￥<?php echo number_format($transaction['amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            $payment_methods = [
                                                1 => '现金',
                                                2 => '信用卡',
                                                3 => '微信',
                                                4 => '支付宝'
                                            ];
                                            echo isset($payment_methods[$transaction['payment_method']]) ? $payment_methods[$transaction['payment_method']] : '未知';
                                            ?>
                                        </td>
                                        <td><?php echo $transaction['operator_name']; ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($transaction['transaction_time'])); ?></td>
                                        <td><?php echo $transaction['remark']; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无押金交易记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <div class="form-buttons">
                    <a href="deposit.php" class="btn btn-secondary">返回</a>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>