<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('customer_marketing');

// 记录访问日志
record_log('访问营销管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加营销活动
    if ($_POST['action'] == 'add') {
        $campaign_name = isset($_POST['campaign_name']) ? trim($_POST['campaign_name']) : '';
        $campaign_type = isset($_POST['campaign_type']) ? intval($_POST['campaign_type']) : 1;
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $target_level_id = isset($_POST['target_level_id']) && $_POST['target_level_id'] ? intval($_POST['target_level_id']) : null;
        $start_time = isset($_POST['start_time']) ? trim($_POST['start_time']) : '';
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($campaign_name) || empty($content) || empty($start_time) || empty($end_time)) {
            $error = '请填写完整营销活动信息！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    INSERT INTO guest_marketing_campaigns (
                        campaign_name, campaign_type, content, target_level_id, 
                        start_time, end_time, status
                    ) VALUES (?, ?, ?, ?, ?, ?, ?)
                ");
                $result = $stmt->execute([
                    $campaign_name,
                    $campaign_type,
                    $content,
                    $target_level_id,
                    $start_time,
                    $end_time,
                    $status
                ]);

                if ($result) {
                    record_log("添加营销活动：{$campaign_name}");
                    $success = '营销活动添加成功！';
                } else {
                    $error = '营销活动添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑营销活动
    elseif ($_POST['action'] == 'edit') {
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;
        $campaign_name = isset($_POST['campaign_name']) ? trim($_POST['campaign_name']) : '';
        $campaign_type = isset($_POST['campaign_type']) ? intval($_POST['campaign_type']) : 1;
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $target_level_id = isset($_POST['target_level_id']) && $_POST['target_level_id'] ? intval($_POST['target_level_id']) : null;
        $start_time = isset($_POST['start_time']) ? trim($_POST['start_time']) : '';
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($campaign_id <= 0 || empty($campaign_name) || empty($content) || empty($start_time) || empty($end_time)) {
            $error = '请填写完整营销活动信息！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    UPDATE guest_marketing_campaigns 
                    SET campaign_name = ?, campaign_type = ?, content = ?, target_level_id = ?, 
                        start_time = ?, end_time = ?, status = ? 
                    WHERE id = ?
                ");
                $result = $stmt->execute([
                    $campaign_name,
                    $campaign_type,
                    $content,
                    $target_level_id,
                    $start_time,
                    $end_time,
                    $status,
                    $campaign_id
                ]);

                if ($result) {
                    record_log("编辑营销活动：{$campaign_name}，ID：{$campaign_id}");
                    $success = '营销活动更新成功！';
                } else {
                    $error = '营销活动更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除营销活动
    elseif ($_POST['action'] == 'delete') {
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;

        if ($campaign_id <= 0) {
            $error = '无效的营销活动ID！';
        } else {
            try {
                // 获取活动名称，用于日志记录
                $stmt = $pdo->prepare("SELECT campaign_name FROM guest_marketing_campaigns WHERE id = ?");
                $stmt->execute([$campaign_id]);
                $campaign = $stmt->fetch();

                if (!$campaign) {
                    $error = '营销活动不存在！';
                } else {
                    $stmt = $pdo->prepare("DELETE FROM guest_marketing_campaigns WHERE id = ?");
                    $result = $stmt->execute([$campaign_id]);

                    if ($result) {
                        record_log("删除营销活动：{$campaign['campaign_name']}，ID：{$campaign_id}");
                        $success = '营销活动删除成功！';
                    } else {
                        $error = '营销活动删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 切换活动状态
    elseif ($_POST['action'] == 'toggle_status') {
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;
        $new_status = isset($_POST['status']) ? intval($_POST['status']) : 0;

        if ($campaign_id <= 0) {
            $error = '无效的营销活动ID！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    UPDATE guest_marketing_campaigns 
                    SET status = ? 
                    WHERE id = ?
                ");
                $result = $stmt->execute([$new_status, $campaign_id]);

                if ($result) {
                    $status_text = $new_status == 1 ? '启用' : '禁用';
                    record_log("切换营销活动状态为{$status_text}，ID：{$campaign_id}");
                    $success = "营销活动{$status_text}成功！";
                } else {
                    $error = '状态切换失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取活动详情
$edit_campaign = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $campaign_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM guest_marketing_campaigns WHERE id = ?");
        $stmt->execute([$campaign_id]);
        $edit_campaign = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取营销活动详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_campaign_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取所有会员等级
try {
    $stmt = $pdo->query("SELECT id, level_name FROM guest_member_levels ORDER BY id");
    $levels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员等级列表失败：' . $e->getMessage();
    $levels = [];
}

// 获取所有营销活动
try {
    $stmt = $pdo->query("
        SELECT c.*, l.level_name 
        FROM guest_marketing_campaigns c
        LEFT JOIN guest_member_levels l ON c.target_level_id = l.id
        ORDER BY c.create_time DESC
    ");
    $campaigns = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取营销活动列表失败：' . $e->getMessage();
    $campaigns = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>营销管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户管理</a> &gt; 营销管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$edit_campaign && !$show_add_form): ?>
                    <a href="marketing.php?show_form=add" class="btn btn-primary">添加营销活动</a>
                <?php endif; ?>
            </div>

            <?php if ($edit_campaign): ?>
                <!-- 编辑营销活动表单 -->
                <h3>编辑营销活动</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="campaign_id" value="<?php echo $edit_campaign['id']; ?>">

                        <div class="form-group">
                            <label for="campaign_name">活动名称：</label>
                            <input type="text" id="campaign_name" name="campaign_name" value="<?php echo $edit_campaign['campaign_name']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="campaign_type">活动类型：</label>
                            <select id="campaign_type" name="campaign_type" required>
                                <option value="1" <?php echo $edit_campaign['campaign_type'] == 1 ? 'selected' : ''; ?>>短信营销</option>
                                <option value="2" <?php echo $edit_campaign['campaign_type'] == 2 ? 'selected' : ''; ?>>邮件营销</option>
                                <option value="3" <?php echo $edit_campaign['campaign_type'] == 3 ? 'selected' : ''; ?>>优惠券</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="content">活动内容：</label>
                            <textarea id="content" name="content" rows="5" required><?php echo $edit_campaign['content']; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="target_level_id">目标会员等级：</label>
                            <select id="target_level_id" name="target_level_id">
                                <option value="">所有等级</option>
                                <?php foreach ($levels as $level): ?>
                                    <option value="<?php echo $level['id']; ?>" <?php echo $edit_campaign['target_level_id'] == $level['id'] ? 'selected' : ''; ?>>
                                        <?php echo $level['level_name']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="start_time">开始时间：</label>
                            <input type="datetime-local" id="start_time" name="start_time" value="<?php echo date('Y-m-d\TH:i', strtotime($edit_campaign['start_time'])); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_time">结束时间：</label>
                            <input type="datetime-local" id="end_time" name="end_time" value="<?php echo date('Y-m-d\TH:i', strtotime($edit_campaign['end_time'])); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo $edit_campaign['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $edit_campaign['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="marketing.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_add_form): ?>
                <!-- 添加营销活动表单 -->
                <h3>添加营销活动</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="campaign_name">活动名称：</label>
                            <input type="text" id="campaign_name" name="campaign_name" required>
                        </div>

                        <div class="form-group">
                            <label for="campaign_type">活动类型：</label>
                            <select id="campaign_type" name="campaign_type" required>
                                <option value="1">短信营销</option>
                                <option value="2">邮件营销</option>
                                <option value="3">优惠券</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="content">活动内容：</label>
                            <textarea id="content" name="content" rows="5" required></textarea>
                        </div>

                        <div class="form-group">
                            <label for="target_level_id">目标会员等级：</label>
                            <select id="target_level_id" name="target_level_id">
                                <option value="">所有等级</option>
                                <?php foreach ($levels as $level): ?>
                                    <option value="<?php echo $level['id']; ?>"><?php echo $level['level_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="start_time">开始时间：</label>
                            <input type="datetime-local" id="start_time" name="start_time" required>
                        </div>

                        <div class="form-group">
                            <label for="end_time">结束时间：</label>
                            <input type="datetime-local" id="end_time" name="end_time" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1">启用</option>
                                <option value="0">禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="marketing.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <h3>营销活动列表</h3>
            <!-- 营销活动列表 -->
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>活动名称</th>
                            <th>活动类型</th>
                            <th>目标等级</th>
                            <th>开始时间</th>
                            <th>结束时间</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($campaigns as $campaign): ?>
                            <tr>
                                <td><?php echo $campaign['id']; ?></td>
                                <td><?php echo $campaign['campaign_name']; ?></td>
                                <td>
                                    <?php
                                    switch ($campaign['campaign_type']) {
                                        case 1:
                                            echo '短信营销';
                                            break;
                                        case 2:
                                            echo '邮件营销';
                                            break;
                                        case 3:
                                            echo '优惠券';
                                            break;
                                        default:
                                            echo '未知';
                                            break;
                                    }
                                    ?>
                                </td>
                                <td><?php echo $campaign['target_level_id'] ? $campaign['level_name'] : '所有等级'; ?></td>
                                <td><?php echo date('Y-m-d H:i', strtotime($campaign['start_time'])); ?></td>
                                <td><?php echo date('Y-m-d H:i', strtotime($campaign['end_time'])); ?></td>
                                <td>
                                    <?php if ($campaign['status'] == 1): ?>
                                        <span class="status-active">启用</span>
                                    <?php else: ?>
                                        <span class="status-inactive">禁用</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="marketing.php?view=<?php echo $campaign['id']; ?>" class="btn btn-sm btn-details">详情</a>

                                    <a href="marketing.php?edit=<?php echo $campaign['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                    <form method="post" action="" style="display:inline;">
                                        <input type="hidden" name="action" value="toggle_status">
                                        <input type="hidden" name="campaign_id" value="<?php echo $campaign['id']; ?>">
                                        <input type="hidden" name="status" value="<?php echo $campaign['status'] == 1 ? 0 : 1; ?>">
                                        <button type="submit" class="btn btn-sm <?php echo $campaign['status'] == 1 ? 'btn-warning' : 'btn-success'; ?>">
                                            <?php echo $campaign['status'] == 1 ? '禁用' : '启用'; ?>
                                        </button>
                                    </form>

                                    <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此营销活动吗？此操作不可恢复！');">
                                        <input type="hidden" name="action" value="delete">
                                        <input type="hidden" name="campaign_id" value="<?php echo $campaign['id']; ?>">
                                        <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                    </form>
                                </td>
                            </tr>
                            <?php if ($view_campaign_id == $campaign['id']): ?>
                                <tr id="campaign-<?php echo $campaign['id']; ?>">
                                    <td colspan="8" class="details-row">
                                        <div class="marketing-content">
                                            <strong>活动内容：</strong>
                                            <p><?php echo nl2br($campaign['content']); ?></p>
                                        </div>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>