<?php
// index.php 主框架页面
session_start();
require_once 'database_config.php';

// 检查用户是否已登录，未登录则重定向到登录页面
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit;
}

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <style>
        /* 基础样式 */
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Microsoft YaHei', Tahoma, Geneva, Verdana, sans-serif;
            background: #f0f2f5;
        }

        /* 侧边栏容器 */
        .sidebar {
            position: fixed;
            left: 0;
            top: 0;
            width: 200px;
            height: 100vh;
            background: #2c3e50;
            padding: 20px 0;
            box-shadow: 2px 0 5px rgba(0, 0, 0, 0.1);
            z-index: 100;
            overflow-y: auto;
        }

        /* 侧边栏导航 */
        .nav-menu {
            list-style: none;
        }

        .nav-item {
            margin: 5px 15px;
        }

        .nav-link {
            display: block;
            padding: 10px 15px;
            color: #ffffff !important;
            text-decoration: none;
            border-radius: 4px;
            transition: all 0.3s;
            font-size: 14px;
        }

        .nav-link:hover {
            background: #34495e;
            color: #ecf0f1;
        }

        /* 返回按钮样式 */
        .back-btn {
            background: #3498db;
            margin-bottom: 20px;
        }

        .back-btn:hover {
            background: #2980b9;
        }

        /* 折叠菜单 */
        .submenu {
            list-style: none;
            margin-left: 15px;
            display: none;
        }

        .nav-item.active .submenu {
            display: block;
        }

        .nav-item.active>a {
            background: #4CAF50;
            color: white !important;
        }

        .submenu .nav-link {
            padding: 8px 15px;
            font-size: 13px;
        }

        /* 选中状态样式 */
        .nav-link.selected {
            background: #4CAF50;
            color: white !important;
        }

        .submenu .nav-link.selected {
            background: #388E3C;
            color: white !important;
        }

        /* 右侧内容区 */
        .content-frame {
            margin-left: 200px;
            height: 100vh;
        }

        iframe {
            width: 100%;
            height: 100%;
            border: none;
            background: #fff;
        }

        /* 用户信息 */
        .user-info {
            color: #fff;
            padding: 10px 20px;
            margin-bottom: 20px;
            border-bottom: 1px solid #34495e;
            font-size: 14px;
        }

        /* 系统标题样式 */
        .main-title {
            text-align: center;
            background-color: #4CAF50;
            padding: 10px 0;
            margin-bottom: 0;
            border-bottom: 1px solid #e0e0e0;
        }

        .main-title h1 {
            margin: 0;
            color: #ffffff;
            font-size: 24px;
            font-weight: normal;
        }

        /* 页脚样式 */
        .main-footer {
            text-align: center;
            background-color: #f5f5f5;
            color: #333;
            padding: 10px 0;
            position: fixed;
            bottom: 0;
            width: calc(100% - 200px);
            margin-left: 0;
            font-size: 14px;
            border-top: 1px solid #e0e0e0;
        }
    </style>
</head>

<body>
    <!-- 侧边栏 -->
    <nav class="sidebar">
        <div class="user-info">
            用户: <?php echo htmlspecialchars($_SESSION['username']); ?>
        </div>
        <ul class="nav-menu">
            <li class="nav-item">
                <a href="logout.php" class="nav-link back-btn">
                    退出登录
                </a>
            </li>

            <!-- 1. 用户与权限管理 -->
            <?php if (has_permission('system')): ?>
                <li class="nav-item" data-module="system">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('system/index.php', 'system')">
                        用户与权限管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="user" onclick="loadPage('system/user.php', 'system', 'user')">用户管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="role" onclick="loadPage('system/role.php', 'system', 'role')">角色权限管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="log" onclick="loadPage('system/log.php', 'system', 'log')">操作日志</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="backup" onclick="loadPage('system/backup.php', 'system', 'backup')">数据备份</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="language" onclick="loadPage('system/language.php', 'system', 'language')">多语言设置</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 2. 预订管理 -->
            <?php if (has_permission('booking')): ?>
                <li class="nav-item" data-module="booking">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('booking/index.php', 'booking')">
                        预订管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="order" onclick="loadPage('booking/order.php', 'booking', 'order')">订单管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="status" onclick="loadPage('booking/status.php', 'booking', 'status')">智能房态管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="remind" onclick="loadPage('booking/remind.php', 'booking', 'remind')">预订提醒</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 3. 入住与退房管理 -->
            <?php if (has_permission('checkin')): ?>
                <li class="nav-item" data-module="checkin">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('checkin/index.php', 'checkin')">
                        入住与退房管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="checkin" onclick="loadPage('checkin/checkin.php', 'checkin', 'checkin')">入住管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="checkout" onclick="loadPage('checkin/checkout.php', 'checkin', 'checkout')">退房管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="deposit" onclick="loadPage('checkin/deposit.php', 'checkin', 'deposit')">押金管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="invoice" onclick="loadPage('checkin/invoice.php', 'checkin', 'invoice')">发票管理</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 4. 客房管理 -->
            <?php if (has_permission('room')): ?>
                <li class="nav-item" data-module="room">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('room/index.php', 'room')">
                        客房管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="status" onclick="loadPage('room/status.php', 'room', 'status')">房态管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="type" onclick="loadPage('room/type.php', 'room', 'type')">房型管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="items" onclick="loadPage('room/items.php', 'room', 'items')">物品管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="cleaning" onclick="loadPage('room/cleaning.php', 'room', 'cleaning')">清洁管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="maintenance" onclick="loadPage('room/maintenance.php', 'room', 'maintenance')">维修管理</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 5. 客户管理 -->
            <?php if (has_permission('customer')): ?>
                <li class="nav-item" data-module="customer">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('customer/index.php', 'customer')">
                        客户管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="member" onclick="loadPage('customer/member.php', 'customer', 'member')">会员管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="complaint" onclick="loadPage('customer/complaint.php', 'customer', 'complaint')">投诉管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="marketing" onclick="loadPage('customer/marketing.php', 'customer', 'marketing')">营销管理</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 6. 财务与结算管理 -->
            <?php if (has_permission('finance')): ?>
                <li class="nav-item" data-module="finance">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('finance/index.php', 'finance')">
                        财务与结算管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="bill" onclick="loadPage('finance/bill.php', 'finance', 'bill')">账单管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="refund" onclick="loadPage('finance/refund.php', 'finance', 'refund')">退款管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="report" onclick="loadPage('finance/report.php', 'finance', 'report')">财务报表</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="commission" onclick="loadPage('finance/commission.php', 'finance', 'commission')">佣金结算</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 7. OTA及渠道管理 -->
            <?php if (has_permission('ota')): ?>
                <li class="nav-item" data-module="ota">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('ota/index.php', 'ota')">
                        OTA及渠道管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="channel" onclick="loadPage('ota/channel.php', 'ota', 'channel')">渠道管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="price" onclick="loadPage('ota/price.php', 'ota', 'price')">价格管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="order" onclick="loadPage('ota/order.php', 'ota', 'order')">订单同步</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="inventory" onclick="loadPage('ota/inventory.php', 'ota', 'inventory')">库存同步</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 8. 物资与库存管理 -->
            <?php if (has_permission('inventory')): ?>
                <li class="nav-item" data-module="inventory">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('inventory/index.php', 'inventory')">
                        物资与库存管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="purchase" onclick="loadPage('inventory/purchase.php', 'inventory', 'purchase')">物资采购</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="stock" onclick="loadPage('inventory/stock.php', 'inventory', 'stock')">库存管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="supplier" onclick="loadPage('inventory/supplier.php', 'inventory', 'supplier')">供应商管理</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 9. 统计与报表 -->
            <?php if (has_permission('statistics')): ?>
                <li class="nav-item" data-module="statistics">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('statistics/index.php', 'statistics')">
                        统计与报表
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="occupancy" onclick="loadPage('statistics/occupancy.php', 'statistics', 'occupancy')">入住率分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="room" onclick="loadPage('statistics/room.php', 'statistics', 'room')">房间利用率</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="order" onclick="loadPage('statistics/order.php', 'statistics', 'order')">订单数据分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="finance" onclick="loadPage('statistics/finance.php', 'statistics', 'finance')">财务报表</a></li>
                    </ul>
                </li>
            <?php endif; ?>


        </ul>
    </nav>

    <!-- 右侧内容区 -->
    <div class="content-frame">
        <div class="main-title">
            <h1><?php echo title; ?></h1>
        </div>
        <iframe name="contentFrame" id="mainFrame" src="system/index.php"></iframe>
        <div class="main-footer">
            版权所有 &copy; CA410 <?php echo date('Y'); ?> <?php echo title; ?>
        </div>
    </div>

    <script>
        // 当前选中的模块和页面
        let currentModule = 'system';
        let currentPage = '';

        // 页面加载函数
        function loadPage(pageUrl, module, page = '') {
            document.getElementById('mainFrame').src = pageUrl;

            // 更新当前选中的模块和页面
            currentModule = module;
            currentPage = page;

            // 更新菜单选中状态
            updateMenuSelection();
        }

        // 更新菜单选中状态
        function updateMenuSelection() {
            // 清除所有选中状态
            const allLinks = document.querySelectorAll('.nav-link');
            allLinks.forEach(link => {
                link.classList.remove('selected');
            });

            // 设置当前模块的选中状态
            const moduleItem = document.querySelector(`.nav-item[data-module="${currentModule}"]`);
            if (moduleItem) {
                const moduleLink = moduleItem.querySelector(':scope > a');
                moduleLink.classList.add('selected');

                // 如果有子页面，设置子页面的选中状态
                if (currentPage) {
                    const pageLink = moduleItem.querySelector(`.submenu .nav-link[data-page="${currentPage}"]`);
                    if (pageLink) {
                        pageLink.classList.add('selected');
                    }
                }
            }
        }

        // 切换子菜单显示/隐藏
        function toggleSubmenu(item) {
            // 先关闭所有已打开的子菜单
            const allItems = document.querySelectorAll('.nav-item');
            allItems.forEach(el => {
                if (el !== item && el.classList.contains('active')) {
                    el.classList.remove('active');
                }
            });

            // 切换当前项的active状态
            item.classList.toggle('active');

            // 更新菜单选中状态
            updateMenuSelection();
        }

        // 初始化加载默认页
        window.onload = function() {
            loadPage('system/index.php', 'system');

            // 默认展开第一个可访问的菜单
            const menuItems = document.querySelectorAll('.nav-item[data-module]');
            if (menuItems.length > 0) {
                // 找到第一个可见的菜单项
                let firstVisibleItem = null;
                menuItems.forEach(item => {
                    if (item.offsetParent !== null && !firstVisibleItem) {
                        firstVisibleItem = item;
                    }
                });

                if (firstVisibleItem) {
                    firstVisibleItem.classList.add('active');
                }
            }
        }
    </script>

</body>

</html>