<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'database_config.php';

// 初始化错误消息变量
$error_msg = '';
// 以下内容需要按照实际数据库表的结构进行修改

// 如果已经登录，则重定向到首页
if (isset($_SESSION['user_id'])) {

    header('Location: index.php');
    exit;
}

// 处理登录表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = trim($_POST['username'] ?? '');
    $password = trim($_POST['password'] ?? '');

    // 简单的输入验证
    if (empty($username) || empty($password)) {
        $error_msg = '用户名和密码不能为空';
    } else {
        try {
            // 在关键步骤添加日志
            error_log("尝试登录用户: " . $_POST['username']);

            // 查询用户
            $stmt = $pdo->prepare("SELECT id, username, password, role_id, status FROM sys_users WHERE username = ?");
            $stmt->execute([$username]);
            $user = $stmt->fetch();

            error_log("用户查询结果: " . ($user ? "找到用户" : "未找到用户"));

            // 验证用户名和密码（使用MD5验证）
            if ($user && $user['password'] === md5($password)) {
                // 检查账号状态
                if ($user['status'] == 0) {
                    $error_msg = '账号已被禁用，请联系管理员';
                } else {
                    // 登录成功，设置会话变量
                    $_SESSION['user_id'] = $user['id'];
                    $_SESSION['username'] = $user['username'];
                    $_SESSION['role_id'] = $user['role_id'];

                    // 记录登录日志
                    record_log('用户登录成功');

                    // 重定向到首页
                    header('Location: index.php');
                    exit;
                }
            } else {
                $error_msg = '用户名或密码错误';
                // 记录失败登录尝试
                if (!empty($username)) {
                    record_log("登录失败: 用户名 {$username}");
                }
            }

            error_log("密码验证结果: " . ($user ? "密码正确" : "密码错误"));
        } catch (PDOException $e) {
            $error_msg = '登录过程中发生错误，请稍后再试';
            error_log("登录错误: " . $e->getMessage());
        } catch (Exception $e) {
            error_log("登录异常: " . $e->getMessage());
            // 显示异常消息
            echo "登录异常: " . $e->getMessage();
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>登录 - <?php echo title; ?></title>
    <style>
        body {
            font-family: 'Microsoft YaHei', Arial, sans-serif;
            background-color: #f8f9fa;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }

        .login-container {
            background-color: white;
            padding: 2rem;
            border-radius: 5px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            width: 100%;
            max-width: 400px;
        }

        .login-header {
            text-align: center;
            margin-bottom: 1.5rem;
        }

        .login-header h1 {
            color: #4CAF50;
            margin: 0;
            font-size: 1.8rem;
        }

        .logo-container {
            margin: 0 auto 15px auto;
            width: 100px;
            height: 100px;
            border-radius: 50%;
            overflow: hidden;
            box-shadow: 0 3px 10px rgba(0, 0, 0, 0.2);
        }

        .logo-container img {
            width: 100%;
            height: 100%;
            object-fit: cover;
        }

        .login-form {
            display: flex;
            flex-direction: column;
        }

        .form-group {
            margin-bottom: 1rem;
        }

        .form-group label {
            display: block;
            margin-bottom: 0.5rem;
            font-weight: bold;
            color: #555;
        }

        .form-control {
            width: 100%;
            padding: 0.7rem;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 1rem;
            box-sizing: border-box;
        }

        .form-control:focus {
            border-color: #4CAF50;
            outline: none;
        }

        .btn-login {
            background-color: #4CAF50;
            color: white;
            border: none;
            padding: 0.8rem;
            font-size: 1rem;
            border-radius: 4px;
            cursor: pointer;
            margin-top: 0.5rem;
        }

        .btn-login:hover {
            background-color: #45a049;
        }

        .error-message {
            color: #f44336;
            margin-bottom: 1rem;
            text-align: center;
        }

        .login-footer {
            text-align: center;
            margin-top: 1.5rem;
            color: #777;
            font-size: 0.9rem;
        }
    </style>
</head>

<body>
    <div class="login-container">
        <div class="login-header">
            <div class="logo-container">
                <img src="img/logo.png" alt="HotelPro Logo">
            </div>
            <h1><?php echo title; ?></h1>
        </div>

        <?php if (!empty($error_msg)): ?>
            <div class="error-message">
                <?php echo htmlspecialchars($error_msg); ?>
            </div>
        <?php endif; ?>

        <form class="login-form" method="post" action="login.php">
            <div class="form-group">
                <label for="username">用户名</label>
                <input type="text" id="username" name="username" class="form-control" required autocomplete="off">
            </div>

            <div class="form-group">
                <label for="password">密码</label>
                <input type="password" id="password" name="password" class="form-control" required>
            </div>

            <button type="submit" class="btn-login">登录</button>
        </form>

        <div class="login-footer">
            &copy; <?php echo date('Y'); ?> <?php echo title; ?>
        </div>
    </div>
</body>

</html>