<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('ota_manage');

// 记录访问日志
record_log('访问OTA渠道管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加渠道
    if ($_POST['action'] == 'add') {
        $channel_code = isset($_POST['channel_code']) ? trim($_POST['channel_code']) : '';
        $channel_name = isset($_POST['channel_name']) ? trim($_POST['channel_name']) : '';
        $commission_rate = isset($_POST['commission_rate']) ? floatval($_POST['commission_rate']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($channel_code) || empty($channel_name)) {
            $error = '请填写完整渠道信息！';
        } else {
            try {
                // 检查渠道代码是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM ota_channels WHERE channel_code = ?");
                $stmt->execute([$channel_code]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '渠道代码已存在！';
                } else {
                    $stmt = $pdo->prepare("
                        INSERT INTO ota_channels (
                            channel_code, channel_name, commission_rate, status
                        ) VALUES (?, ?, ?, ?)
                    ");
                    $result = $stmt->execute([
                        $channel_code,
                        $channel_name,
                        $commission_rate,
                        $status
                    ]);

                    if ($result) {
                        record_log("添加OTA渠道：{$channel_name}，代码：{$channel_code}");
                        $success = 'OTA渠道添加成功！';
                    } else {
                        $error = 'OTA渠道添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑渠道
    elseif ($_POST['action'] == 'edit') {
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;
        $channel_code = isset($_POST['channel_code']) ? trim($_POST['channel_code']) : '';
        $channel_name = isset($_POST['channel_name']) ? trim($_POST['channel_name']) : '';
        $commission_rate = isset($_POST['commission_rate']) ? floatval($_POST['commission_rate']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($channel_id <= 0 || empty($channel_code) || empty($channel_name)) {
            $error = '请填写完整渠道信息！';
        } else {
            try {
                // 检查渠道代码是否已存在（排除当前渠道）
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM ota_channels WHERE channel_code = ? AND id != ?");
                $stmt->execute([$channel_code, $channel_id]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '渠道代码已存在！';
                } else {
                    $stmt = $pdo->prepare("
                        UPDATE ota_channels 
                        SET channel_code = ?, channel_name = ?, commission_rate = ?, status = ? 
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([
                        $channel_code,
                        $channel_name,
                        $commission_rate,
                        $status,
                        $channel_id
                    ]);

                    if ($result) {
                        record_log("编辑OTA渠道：{$channel_name}，代码：{$channel_code}");
                        $success = 'OTA渠道更新成功！';
                    } else {
                        $error = 'OTA渠道更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除渠道
    elseif ($_POST['action'] == 'delete') {
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;

        if ($channel_id <= 0) {
            $error = '无效的渠道ID！';
        } else {
            try {
                // 获取渠道信息，用于日志记录
                $stmt = $pdo->prepare("SELECT channel_name, channel_code FROM ota_channels WHERE id = ?");
                $stmt->execute([$channel_id]);
                $channel = $stmt->fetch();

                if (!$channel) {
                    $error = '渠道不存在！';
                } else {
                    // 检查是否有关联的房价数据
                    $stmt = $pdo->prepare("SELECT COUNT(*) FROM ota_room_rates WHERE channel_id = ?");
                    $stmt->execute([$channel_id]);
                    if ($stmt->fetchColumn() > 0) {
                        $error = '该渠道存在关联的房价数据，无法删除！请先删除该渠道下的所有房价数据。';
                    } else {
                        $stmt = $pdo->prepare("DELETE FROM ota_channels WHERE id = ?");
                        $result = $stmt->execute([$channel_id]);

                        if ($result) {
                            record_log("删除OTA渠道：{$channel['channel_name']}，代码：{$channel['channel_code']}");
                            $success = 'OTA渠道删除成功！';
                        } else {
                            $error = 'OTA渠道删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取渠道详情
$edit_channel = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $channel_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM ota_channels WHERE id = ?");
        $stmt->execute([$channel_id]);
        $edit_channel = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取渠道详情失败：' . $e->getMessage();
    }
}

// 获取所有渠道
try {
    $stmt = $pdo->query("SELECT * FROM ota_channels ORDER BY id");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取渠道列表失败：' . $e->getMessage();
    $channels = [];
}

// 获取渠道关联的房价数量
$channel_rate_counts = [];
try {
    $stmt = $pdo->query("
        SELECT channel_id, COUNT(*) as rate_count 
        FROM ota_room_rates 
        GROUP BY channel_id
    ");
    while ($row = $stmt->fetch()) {
        $channel_rate_counts[$row['channel_id']] = $row['rate_count'];
    }
} catch (PDOException $e) {
    $error = '获取渠道关联数据失败：' . $e->getMessage();
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>OTA渠道管理</h2>
            <div class="breadcrumb">
                <a href="index.php">OTA及渠道管理</a> &gt; 渠道管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$edit_channel): ?>
                    <a href="channel.php?show_form=add" class="btn btn-primary">添加渠道</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加渠道表单 -->
                <h3>添加OTA渠道</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="channel_code">渠道代码：</label>
                            <input type="text" id="channel_code" name="channel_code" required>
                            <p class="form-hint">英文字母和数字，不含空格，如：ctrip, fliggy</p>
                        </div>

                        <div class="form-group">
                            <label for="channel_name">渠道名称：</label>
                            <input type="text" id="channel_name" name="channel_name" required>
                        </div>

                        <div class="form-group">
                            <label for="commission_rate">佣金比例（%）：</label>
                            <input type="number" id="commission_rate" name="commission_rate" min="0" max="100" step="0.01" value="0">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1">启用</option>
                                <option value="0">禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="channel.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($edit_channel): ?>
                <!-- 编辑渠道表单 -->
                <h3>编辑OTA渠道</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="channel_id" value="<?php echo $edit_channel['id']; ?>">

                        <div class="form-group">
                            <label for="channel_code">渠道代码：</label>
                            <input type="text" id="channel_code" name="channel_code" value="<?php echo $edit_channel['channel_code']; ?>" required>
                            <p class="form-hint">英文字母和数字，不含空格，如：ctrip, fliggy</p>
                        </div>

                        <div class="form-group">
                            <label for="channel_name">渠道名称：</label>
                            <input type="text" id="channel_name" name="channel_name" value="<?php echo $edit_channel['channel_name']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="commission_rate">佣金比例（%）：</label>
                            <input type="number" id="commission_rate" name="commission_rate" min="0" max="100" step="0.01" value="<?php echo $edit_channel['commission_rate']; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo $edit_channel['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $edit_channel['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="channel.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <h3>OTA渠道列表</h3>
                <!-- 渠道列表 -->
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>渠道代码</th>
                                <th>渠道名称</th>
                                <th>佣金比例</th>
                                <th>关联房价数</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($channels as $channel): ?>
                                <tr>
                                    <td><?php echo $channel['id']; ?></td>
                                    <td><?php echo $channel['channel_code']; ?></td>
                                    <td><?php echo $channel['channel_name']; ?></td>
                                    <td><?php echo $channel['commission_rate']; ?>%</td>
                                    <td><?php echo isset($channel_rate_counts[$channel['id']]) ? $channel_rate_counts[$channel['id']] : 0; ?></td>
                                    <td>
                                        <?php if ($channel['status'] == 1): ?>
                                            <span class="status-active">启用</span>
                                        <?php else: ?>
                                            <span class="status-inactive">禁用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <a href="channel.php?edit=<?php echo $channel['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <a href="price.php?channel_id=<?php echo $channel['id']; ?>" class="btn btn-sm btn-details">房价</a>

                                        <?php if (!isset($channel_rate_counts[$channel['id']]) || $channel_rate_counts[$channel['id']] == 0): ?>
                                            <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此渠道吗？此操作不可恢复！');">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="channel_id" value="<?php echo $channel['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>