<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('ota_order');

// 记录访问日志
record_log('访问OTA订单管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加OTA订单
    if ($_POST['action'] == 'add') {
        $booking_no = 'OTA' . date('YmdHis') . rand(100, 999); // 生成OTA预订编号
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;
        $guest_name = isset($_POST['guest_name']) ? trim($_POST['guest_name']) : '';
        $guest_mobile = isset($_POST['guest_mobile']) ? trim($_POST['guest_mobile']) : '';
        $guest_email = isset($_POST['guest_email']) ? trim($_POST['guest_email']) : '';
        $id_number = isset($_POST['id_number']) ? trim($_POST['id_number']) : '';
        $arrival_date = isset($_POST['arrival_date']) ? trim($_POST['arrival_date']) : '';
        $departure_date = isset($_POST['departure_date']) ? trim($_POST['departure_date']) : '';
        $room_type_id = isset($_POST['room_type_id']) ? intval($_POST['room_type_id']) : 0;
        $room_count = isset($_POST['room_count']) ? intval($_POST['room_count']) : 1;
        $room_rate = isset($_POST['room_rate']) ? floatval($_POST['room_rate']) : 0;
        $breakfast = isset($_POST['breakfast']) ? intval($_POST['breakfast']) : 0;
        $total_amount = isset($_POST['total_amount']) ? floatval($_POST['total_amount']) : 0;
        $special_request = isset($_POST['special_request']) ? trim($_POST['special_request']) : '';
        $ota_order_no = isset($_POST['ota_order_no']) ? trim($_POST['ota_order_no']) : '';
        $status = 1; // 待确认

        if ($channel_id <= 0 || empty($guest_name) || empty($guest_mobile) || empty($arrival_date) || empty($departure_date) || $room_type_id <= 0 || $room_rate <= 0) {
            $error = '请填写完整的订单信息！';
        } else {
            try {
                $pdo->beginTransaction();

                // 插入预订主表
                $stmt = $pdo->prepare("
                    INSERT INTO booking_orders (
                        booking_no, guest_name, guest_mobile, guest_email, id_number, 
                        channel_id, arrival_date, departure_date, room_type_id, room_count, 
                        room_rate, breakfast, total_amount, special_request, status
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                ");

                $result = $stmt->execute([
                    $booking_no,
                    $guest_name,
                    $guest_mobile,
                    $guest_email,
                    $id_number,
                    $channel_id,
                    $arrival_date,
                    $departure_date,
                    $room_type_id,
                    $room_count,
                    $room_rate,
                    $breakfast,
                    $total_amount,
                    $special_request,
                    $status
                ]);

                if ($result) {
                    $booking_id = $pdo->lastInsertId();

                    // 添加OTA佣金记录
                    $stmt = $pdo->prepare("SELECT commission_rate FROM ota_channels WHERE id = ?");
                    $stmt->execute([$channel_id]);
                    $channel = $stmt->fetch();

                    if ($channel) {
                        $commission_rate = $channel['commission_rate'];
                        $commission_amount = round($total_amount * $commission_rate / 100, 2);

                        $stmt = $pdo->prepare("
                            INSERT INTO finance_commissions (
                                channel_id, booking_id, amount, commission_rate, commission_amount, settlement_status
                            ) VALUES (?, ?, ?, ?, ?, 1)
                        ");
                        $stmt->execute([
                            $channel_id,
                            $booking_id,
                            $total_amount,
                            $commission_rate,
                            $commission_amount
                        ]);
                    }

                    $pdo->commit();
                    record_log("添加OTA订单：{$booking_no}，渠道ID：{$channel_id}");
                    $success = 'OTA订单添加成功！';
                } else {
                    $pdo->rollBack();
                    $error = 'OTA订单添加失败！';
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 同步OTA订单
    elseif ($_POST['action'] == 'sync') {
        $channel_id = isset($_POST['sync_channel_id']) ? intval($_POST['sync_channel_id']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';

        if ($channel_id <= 0 || empty($start_date) || empty($end_date)) {
            $error = '请选择渠道和日期范围！';
        } else {
            try {
                // 这里应该有实际的API调用代码来同步OTA订单
                // 这里只是模拟同步成功，实际项目中需要替换为真实的API调用

                // 模拟随机同步成功的订单数
                $sync_count = rand(1, 5);

                record_log("同步OTA订单：渠道ID {$channel_id}，日期范围 {$start_date} 至 {$end_date}");
                $success = "OTA订单同步成功！共同步 {$sync_count} 条订单。";
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 确认OTA订单
    elseif ($_POST['action'] == 'confirm') {
        $booking_id = isset($_POST['booking_id']) ? intval($_POST['booking_id']) : 0;

        if ($booking_id <= 0) {
            $error = '无效的订单ID！';
        } else {
            try {
                // 更新订单状态为已确认
                $stmt = $pdo->prepare("UPDATE booking_orders SET status = 2 WHERE id = ?");
                $result = $stmt->execute([$booking_id]);

                if ($result) {
                    // 获取订单信息用于日志记录
                    $stmt = $pdo->prepare("SELECT booking_no FROM booking_orders WHERE id = ?");
                    $stmt->execute([$booking_id]);
                    $booking = $stmt->fetch();

                    record_log("确认OTA订单：{$booking['booking_no']}");
                    $success = 'OTA订单确认成功！';
                } else {
                    $error = 'OTA订单确认失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 取消OTA订单
    elseif ($_POST['action'] == 'cancel') {
        $booking_id = isset($_POST['booking_id']) ? intval($_POST['booking_id']) : 0;
        $cancel_reason = isset($_POST['cancel_reason']) ? trim($_POST['cancel_reason']) : '';

        if ($booking_id <= 0) {
            $error = '无效的订单ID！';
        } else {
            try {
                // 更新订单状态为已取消
                $stmt = $pdo->prepare("UPDATE booking_orders SET status = 3 WHERE id = ?");
                $result = $stmt->execute([$booking_id]);

                if ($result) {
                    // 获取订单信息用于日志记录
                    $stmt = $pdo->prepare("SELECT booking_no FROM booking_orders WHERE id = ?");
                    $stmt->execute([$booking_id]);
                    $booking = $stmt->fetch();

                    record_log("取消OTA订单：{$booking['booking_no']}，原因：{$cancel_reason}");
                    $success = 'OTA订单取消成功！';
                } else {
                    $error = 'OTA订单取消失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 设置默认查询日期范围
$today = date('Y-m-d');
$default_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-7 days'));
$default_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : $today;

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 判断是否显示同步表单
$show_sync_form = isset($_GET['show_form']) && $_GET['show_form'] == 'sync';

// 获取OTA渠道列表
try {
    $stmt = $pdo->query("SELECT id, channel_code, channel_name FROM ota_channels WHERE status = 1 ORDER BY id");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取OTA渠道列表失败：' . $e->getMessage();
    $channels = [];
}

// 获取房型列表
try {
    $stmt = $pdo->query("SELECT id, type_name, price FROM room_types WHERE status = 1 ORDER BY id");
    $room_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型列表失败：' . $e->getMessage();
    $room_types = [];
}

// 查看详情
$view_booking_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取OTA订单列表
try {
    $filter_channel = isset($_GET['channel_id']) ? intval($_GET['channel_id']) : 0;
    $filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;

    $where_clauses = [];
    $params = [];

    // 只查询OTA渠道的订单
    $where_clauses[] = "b.channel_id IN (SELECT id FROM ota_channels)";

    if ($filter_channel > 0) {
        $where_clauses[] = "b.channel_id = ?";
        $params[] = $filter_channel;
    }

    if ($filter_status > 0) {
        $where_clauses[] = "b.status = ?";
        $params[] = $filter_status;
    }

    // 添加日期范围筛选
    $where_clauses[] = "b.create_time BETWEEN ? AND ?";
    $params[] = $default_start_date . ' 00:00:00';
    $params[] = $default_end_date . ' 23:59:59';

    $where_sql = implode(" AND ", $where_clauses);

    $stmt = $pdo->prepare("
        SELECT b.*, c.channel_name, c.channel_code, rt.type_name 
        FROM booking_orders b
        JOIN ota_channels c ON b.channel_id = c.id
        JOIN room_types rt ON b.room_type_id = rt.id
        WHERE {$where_sql}
        ORDER BY b.create_time DESC
    ");
    $stmt->execute($params);
    $bookings = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取OTA订单列表失败：' . $e->getMessage();
    $bookings = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>OTA订单管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>OTA订单管理</h2>
            <div class="breadcrumb">
                <a href="index.php">OTA管理</a> &gt; 订单管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$show_sync_form): ?>
                    <a href="order.php?show_form=add" class="btn btn-primary">手动添加</a>
                    <a href="order.php?show_form=sync" class="btn btn-success">同步订单</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加OTA订单表单 -->
                <h3>手动添加OTA订单</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="channel_id">OTA渠道：</label>
                            <select id="channel_id" name="channel_id" required>
                                <option value="">请选择OTA渠道</option>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>"><?php echo $channel['channel_name']; ?> (<?php echo $channel['channel_code']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="ota_order_no">平台订单号：</label>
                            <input type="text" id="ota_order_no" name="ota_order_no" required>
                        </div>

                        <div class="form-group">
                            <label for="guest_name">客人姓名：</label>
                            <input type="text" id="guest_name" name="guest_name" required>
                        </div>

                        <div class="form-group">
                            <label for="guest_mobile">联系电话：</label>
                            <input type="text" id="guest_mobile" name="guest_mobile" required>
                        </div>

                        <div class="form-group">
                            <label for="guest_email">电子邮箱：</label>
                            <input type="email" id="guest_email" name="guest_email">
                        </div>

                        <div class="form-group">
                            <label for="id_number">证件号码：</label>
                            <input type="text" id="id_number" name="id_number">
                        </div>

                        <div class="form-group">
                            <label for="arrival_date">入住日期：</label>
                            <input type="date" id="arrival_date" name="arrival_date" required>
                        </div>

                        <div class="form-group">
                            <label for="departure_date">离店日期：</label>
                            <input type="date" id="departure_date" name="departure_date" required>
                        </div>

                        <div class="form-group">
                            <label for="room_type_id">房型：</label>
                            <select id="room_type_id" name="room_type_id" required>
                                <option value="">请选择房型</option>
                                <?php foreach ($room_types as $type): ?>
                                    <option value="<?php echo $type['id']; ?>"><?php echo $type['type_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="room_count">房间数量：</label>
                            <input type="number" id="room_count" name="room_count" min="1" value="1" required>
                        </div>

                        <div class="form-group">
                            <label for="room_rate">房价(元/晚)：</label>
                            <input type="number" id="room_rate" name="room_rate" step="0.01" min="0" required>
                        </div>

                        <div class="form-group">
                            <label for="breakfast">含早：</label>
                            <select id="breakfast" name="breakfast">
                                <option value="0">不含早</option>
                                <option value="1">含单早</option>
                                <option value="2">含双早</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="total_amount">订单总金额：</label>
                            <input type="number" id="total_amount" name="total_amount" step="0.01" min="0" required>
                        </div>

                        <div class="form-group">
                            <label for="special_request">特殊要求：</label>
                            <textarea id="special_request" name="special_request" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="order.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_sync_form): ?>
                <!-- 同步OTA订单表单 -->
                <h3>同步OTA订单</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="sync">

                        <div class="form-group">
                            <label for="sync_channel_id">OTA渠道：</label>
                            <select id="sync_channel_id" name="sync_channel_id" required>
                                <option value="">请选择OTA渠道</option>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>"><?php echo $channel['channel_name']; ?> (<?php echo $channel['channel_code']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $default_start_date; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $default_end_date; ?>" required>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">开始同步</button>
                            <a href="order.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_add_form && !$show_sync_form): ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="channel_id">OTA渠道：</label>
                                <select id="channel_id" name="channel_id">
                                    <option value="0">所有渠道</option>
                                    <?php foreach ($channels as $channel): ?>
                                        <option value="<?php echo $channel['id']; ?>" <?php echo $filter_channel == $channel['id'] ? 'selected' : ''; ?>><?php echo $channel['channel_name']; ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="status">订单状态：</label>
                                <select id="status" name="status">
                                    <option value="0">所有状态</option>
                                    <option value="1" <?php echo $filter_status == 1 ? 'selected' : ''; ?>>待确认</option>
                                    <option value="2" <?php echo $filter_status == 2 ? 'selected' : ''; ?>>已确认</option>
                                    <option value="3" <?php echo $filter_status == 3 ? 'selected' : ''; ?>>已取消</option>
                                    <option value="4" <?php echo $filter_status == 4 ? 'selected' : ''; ?>>已入住</option>
                                    <option value="5" <?php echo $filter_status == 5 ? 'selected' : ''; ?>>已退房</option>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="filter_start_date">开始日期：</label>
                                <input type="date" id="filter_start_date" name="start_date" value="<?php echo $default_start_date; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="filter_end_date">结束日期：</label>
                                <input type="date" id="filter_end_date" name="end_date" value="<?php echo $default_end_date; ?>">
                            </div>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- OTA订单列表 -->
                <h3>OTA订单列表</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>渠道</th>
                                <th>客人姓名</th>
                                <th>联系电话</th>
                                <th>房型</th>
                                <th>入住日期</th>
                                <th>离店日期</th>
                                <th>总金额</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($bookings as $booking): ?>
                                <tr>
                                    <td><?php echo $booking['booking_no']; ?></td>
                                    <td><?php echo $booking['channel_name']; ?></td>
                                    <td><?php echo $booking['guest_name']; ?></td>
                                    <td><?php echo $booking['guest_mobile']; ?></td>
                                    <td><?php echo $booking['type_name']; ?></td>
                                    <td><?php echo $booking['arrival_date']; ?></td>
                                    <td><?php echo $booking['departure_date']; ?></td>
                                    <td><?php echo number_format($booking['total_amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        $status_text = '';
                                        $status_class = '';
                                        switch ($booking['status']) {
                                            case 1:
                                                $status_text = '待确认';
                                                $status_class = 'status-warning';
                                                break;
                                            case 2:
                                                $status_text = '已确认';
                                                $status_class = 'status-active';
                                                break;
                                            case 3:
                                                $status_text = '已取消';
                                                $status_class = 'status-inactive';
                                                break;
                                            case 4:
                                                $status_text = '已入住';
                                                $status_class = 'status-active';
                                                break;
                                            case 5:
                                                $status_text = '已退房';
                                                $status_class = 'status-inactive';
                                                break;
                                        }
                                        ?>
                                        <span class="<?php echo $status_class; ?>"><?php echo $status_text; ?></span>
                                    </td>
                                    <td>
                                        <a href="order.php?view=<?php echo $booking['id']; ?>" class="btn btn-sm btn-details">详情</a>

                                        <?php if ($booking['status'] == 1): ?>
                                            <form method="post" action="" style="display:inline;">
                                                <input type="hidden" name="action" value="confirm">
                                                <input type="hidden" name="booking_id" value="<?php echo $booking['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-success">确认</button>
                                            </form>
                                        <?php endif; ?>

                                        <?php if ($booking['status'] == 1 || $booking['status'] == 2): ?>
                                            <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要取消此订单吗？');">
                                                <input type="hidden" name="action" value="cancel">
                                                <input type="hidden" name="booking_id" value="<?php echo $booking['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger">取消</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                                <?php if ($view_booking_id == $booking['id']): ?>
                                    <tr>
                                        <td colspan="10" class="details-row">
                                            <div class="booking-details">
                                                <div class="booking-info">
                                                    <h4>订单详情</h4>
                                                    <p><strong>订单编号：</strong> <?php echo $booking['booking_no']; ?></p>
                                                    <p><strong>渠道：</strong> <?php echo $booking['channel_name']; ?> (<?php echo $booking['channel_code']; ?>)</p>
                                                    <p><strong>客人姓名：</strong> <?php echo $booking['guest_name']; ?></p>
                                                    <p><strong>联系电话：</strong> <?php echo $booking['guest_mobile']; ?></p>
                                                    <p><strong>电子邮箱：</strong> <?php echo $booking['guest_email'] ?: '-'; ?></p>
                                                    <p><strong>证件号码：</strong> <?php echo $booking['id_number'] ?: '-'; ?></p>
                                                    <p><strong>房型：</strong> <?php echo $booking['type_name']; ?></p>
                                                    <p><strong>房间数量：</strong> <?php echo $booking['room_count']; ?></p>
                                                    <p><strong>入住日期：</strong> <?php echo $booking['arrival_date']; ?></p>
                                                    <p><strong>离店日期：</strong> <?php echo $booking['departure_date']; ?></p>
                                                    <p><strong>房价：</strong> ￥<?php echo number_format($booking['room_rate'], 2); ?>/晚</p>
                                                    <p><strong>含早：</strong>
                                                        <?php
                                                        switch ($booking['breakfast']) {
                                                            case 0:
                                                                echo '不含早';
                                                                break;
                                                            case 1:
                                                                echo '含单早';
                                                                break;
                                                            case 2:
                                                                echo '含双早';
                                                                break;
                                                        }
                                                        ?>
                                                    </p>
                                                    <p><strong>订单总金额：</strong> ￥<?php echo number_format($booking['total_amount'], 2); ?></p>
                                                    <p><strong>已付金额：</strong> ￥<?php echo number_format($booking['paid_amount'], 2); ?></p>
                                                    <p><strong>特殊要求：</strong> <?php echo $booking['special_request'] ?: '-'; ?></p>
                                                    <p><strong>创建时间：</strong> <?php echo $booking['create_time']; ?></p>
                                                    <p><strong>最后更新：</strong> <?php echo $booking['update_time']; ?></p>
                                                </div>

                                                <?php
                                                // 获取订单佣金信息
                                                try {
                                                    $stmt = $pdo->prepare("
                                                    SELECT * FROM finance_commissions 
                                                    WHERE booking_id = ?
                                                ");
                                                    $stmt->execute([$booking['id']]);
                                                    $commission = $stmt->fetch();

                                                    if ($commission):
                                                ?>
                                                        <div class="booking-commission">
                                                            <h4>佣金信息</h4>
                                                            <p><strong>佣金比例：</strong> <?php echo $commission['commission_rate']; ?>%</p>
                                                            <p><strong>佣金金额：</strong> ￥<?php echo number_format($commission['commission_amount'], 2); ?></p>
                                                            <p><strong>结算状态：</strong>
                                                                <?php
                                                                if ($commission['settlement_status'] == 1) {
                                                                    echo '<span class="status-warning">未结算</span>';
                                                                } else {
                                                                    echo '<span class="status-active">已结算</span>';
                                                                }
                                                                ?>
                                                            </p>
                                                            <?php if ($commission['settlement_status'] == 2): ?>
                                                                <p><strong>结算时间：</strong> <?php echo $commission['settlement_time']; ?></p>
                                                                <p><strong>结算批次：</strong> <?php echo $commission['settlement_batch']; ?></p>
                                                            <?php endif; ?>
                                                        </div>
                                                <?php
                                                    endif;
                                                } catch (PDOException $e) {
                                                    // 忽略错误
                                                }
                                                ?>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>

                            <?php if (count($bookings) == 0): ?>
                                <tr>
                                    <td colspan="10" class="text-center">暂无OTA订单数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 计算订单总金额
        document.addEventListener('DOMContentLoaded', function() {
            const roomRateInput = document.getElementById('room_rate');
            const arrivalDateInput = document.getElementById('arrival_date');
            const departureDateInput = document.getElementById('departure_date');
            const roomCountInput = document.getElementById('room_count');
            const totalAmountInput = document.getElementById('total_amount');

            // 计算总金额的函数
            function calculateTotalAmount() {
                if (!roomRateInput || !arrivalDateInput || !departureDateInput || !roomCountInput || !totalAmountInput) {
                    return;
                }

                const roomRate = parseFloat(roomRateInput.value) || 0;
                const arrivalDate = new Date(arrivalDateInput.value);
                const departureDate = new Date(departureDateInput.value);
                const roomCount = parseInt(roomCountInput.value) || 1;

                if (isNaN(arrivalDate.getTime()) || isNaN(departureDate.getTime())) {
                    return;
                }

                // 计算入住天数
                const timeDiff = departureDate.getTime() - arrivalDate.getTime();
                const nights = Math.ceil(timeDiff / (1000 * 3600 * 24));

                if (nights > 0) {
                    // 计算总金额
                    const totalAmount = roomRate * nights * roomCount;
                    totalAmountInput.value = totalAmount.toFixed(2);
                }
            }

            // 添加事件监听器
            if (roomRateInput) roomRateInput.addEventListener('input', calculateTotalAmount);
            if (arrivalDateInput) arrivalDateInput.addEventListener('change', calculateTotalAmount);
            if (departureDateInput) departureDateInput.addEventListener('change', calculateTotalAmount);
            if (roomCountInput) roomCountInput.addEventListener('input', calculateTotalAmount);
        });
    </script>
</body>

</html>